@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, earthobservations developers.
+# Copyright (C) 2018-2021, earthobservations developers.
 # Distributed under the MIT License. See LICENSE for more info.
 import logging
 from io import BytesIO
@@ -13,7 +13,6 @@ from wetterdienst.provider.dwd.metadata.column_map import (
     GERMAN_TO_ENGLISH_COLUMNS_MAPPING,
 )
 from wetterdienst.provider.dwd.metadata.column_names import DwdColumns, DwdOrigColumns
-from wetterdienst.provider.dwd.metadata.constants import NA_STRING, STATION_DATA_SEP
 from wetterdienst.provider.dwd.metadata.datetime import DatetimeFormat
 from wetterdienst.provider.dwd.observation.metadata.dataset import DwdObservationDataset
 from wetterdienst.provider.dwd.observation.metadata.parameter import (
@@ -96,9 +95,9 @@ def _parse_climate_observations_data(
     try:
         df = pd.read_csv(
             filepath_or_buffer=file,  # prevent leading/trailing whitespace
-            sep=STATION_DATA_SEP,
+            sep=";",
             dtype="str",
-            na_values=NA_STRING,
+            na_values="-999",
             encoding="latin1",
             skipinitialspace=True,
         )
@@ -116,7 +115,7 @@ def _parse_climate_observations_data(
     df = df.rename(columns=str.lower)
 
     # End of record (EOR) has no value, so drop it right away.
-    df = df.drop(columns=DwdColumns.EOR.value, errors="ignore")
+    df = df.drop(columns=[DwdColumns.EOR.value, "struktur_version"], errors="ignore")
 
     if resolution == Resolution.MINUTE_1 and dataset == DwdObservationDataset.PRECIPITATION:
         # Need to unfold historical data, as it is encoded in its run length e.g.
@@ -159,6 +158,16 @@ def _parse_climate_observations_data(
                 if parameter not in df:
                     df[parameter] = pd.NA
 
+    if resolution == Resolution.MINUTE_5 and dataset == DwdObservationDataset.PRECIPITATION:
+        # apparently historical datasets differ from recent and now having all columns as described in the
+        # parameter enumeration when recent and now datasets only have precipitation form and
+        # precipitation height but not rocker and droplet information
+        columns = [DwdOrigColumns.STATION_ID.value, DwdOrigColumns.DATE.value]
+        for parameter in DwdObservationParameter[resolution.name][dataset.name]:
+            columns.append(parameter.value)
+
+        df = df.reindex(columns=columns)
+
     # Special handling for hourly solar data, as it has more date columns
     if resolution == Resolution.HOURLY and dataset == DwdObservationDataset.SOLAR:
         # Rename date column correctly to end of interval, as it has additional minute
